# generated by datamodel-codegen:
#   filename:  schema/entity/services/databaseService.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from enum import Enum
from typing import Optional, Union

from pydantic import BaseModel, Extra, Field

from ...type import basic, entityHistory, entityReference
from .connections.database import (
    athenaConnection,
    azureSQLConnection,
    bigQueryConnection,
    clickhouseConnection,
    databricksConnection,
    db2Connection,
    deltaLakeConnection,
    druidConnection,
    dynamoDBConnection,
    glueConnection,
    hiveConnection,
    mariaDBConnection,
    mssqlConnection,
    mysqlConnection,
    oracleConnection,
    postgresConnection,
    prestoConnection,
    redshiftConnection,
    salesforceConnection,
    sampleDataConnection,
    singleStoreConnection,
    snowflakeConnection,
    sqliteConnection,
    trinoConnection,
    verticaConnection,
)


class DatabaseServiceType(Enum):
    BigQuery = 'BigQuery'
    Mysql = 'Mysql'
    Redshift = 'Redshift'
    Snowflake = 'Snowflake'
    Postgres = 'Postgres'
    Mssql = 'Mssql'
    Hive = 'Hive'
    Oracle = 'Oracle'
    Athena = 'Athena'
    Presto = 'Presto'
    Trino = 'Trino'
    Vertica = 'Vertica'
    Glue = 'Glue'
    MariaDB = 'MariaDB'
    Druid = 'Druid'
    Db2 = 'Db2'
    Clickhouse = 'Clickhouse'
    Databricks = 'Databricks'
    DynamoDB = 'DynamoDB'
    AzureSQL = 'AzureSQL'
    SingleStore = 'SingleStore'
    SQLite = 'SQLite'
    DeltaLake = 'DeltaLake'
    Salesforce = 'Salesforce'
    SampleData = 'SampleData'


class DatabaseConnection(BaseModel):
    class Config:
        extra = Extra.forbid

    config: Optional[
        Union[
            bigQueryConnection.BigQueryConnection,
            athenaConnection.AthenaConnection,
            azureSQLConnection.AzureSQLConnection,
            clickhouseConnection.ClickhouseConnection,
            databricksConnection.DatabricksConnection,
            db2Connection.Db2Connection,
            deltaLakeConnection.DeltaLakeConnection,
            druidConnection.DruidConnection,
            dynamoDBConnection.DynamoDBConnection,
            glueConnection.GlueConnection,
            hiveConnection.HiveConnection,
            mariaDBConnection.MariaDBConnection,
            mssqlConnection.MssqlConnection,
            mysqlConnection.MysqlConnection,
            sqliteConnection.SQLiteConnection,
            oracleConnection.OracleConnection,
            postgresConnection.PostgresConnection,
            prestoConnection.PrestoConnection,
            redshiftConnection.RedshiftConnection,
            salesforceConnection.SalesforceConnection,
            singleStoreConnection.SingleStoreConnection,
            snowflakeConnection.SnowflakeConnection,
            trinoConnection.TrinoConnection,
            verticaConnection.VerticaConnection,
            sampleDataConnection.SampleDataConnection,
        ]
    ] = None


class DatabaseService(BaseModel):
    class Config:
        extra = Extra.forbid

    id: basic.Uuid = Field(
        ..., description='Unique identifier of this database service instance.'
    )
    name: basic.EntityName = Field(
        ..., description='Name that identifies this database service.'
    )
    displayName: Optional[str] = Field(
        None, description='Display Name that identifies this database service.'
    )
    serviceType: DatabaseServiceType = Field(
        ...,
        description='Type of database service such as MySQL, BigQuery, Snowflake, Redshift, Postgres...',
    )
    description: Optional[str] = Field(
        None, description='Description of a database service instance.'
    )
    connection: DatabaseConnection
    pipelines: Optional[entityReference.EntityReferenceList] = Field(
        None,
        description='References to pipelines deployed for this database service to extract metadata, usage, lineage etc..',
    )
    version: Optional[entityHistory.EntityVersion] = Field(
        None, description='Metadata version of the entity.'
    )
    updatedAt: Optional[basic.Timestamp] = Field(
        None,
        description='Last update time corresponding to the new version of the entity in Unix epoch time milliseconds.',
    )
    updatedBy: Optional[str] = Field(None, description='User who made the update.')
    owner: Optional[entityReference.EntityReference] = Field(
        None, description='Owner of this database service.'
    )
    href: Optional[basic.Href] = Field(
        None, description='Link to the resource corresponding to this database service.'
    )
    changeDescription: Optional[entityHistory.ChangeDescription] = Field(
        None, description='Change that lead to this version of the entity.'
    )
    deleted: Optional[bool] = Field(
        False, description='When `true` indicates the entity has been soft deleted.'
    )



# generated by datamodel-codegen:
#   filename:  schema/entity/policies/lifecycle/moveAction.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field, conint

from ....type import storage
from ...data import location
from ...services import storageService


class Destination(BaseModel):
    class Config:
        extra = Extra.forbid

    storageServiceType: Optional[storageService.StorageService] = Field(
        None, description='The storage service to move this entity to.'
    )
    storageClassType: Optional[storage.StorageClassType] = Field(
        None, description='The storage class to move this entity to.'
    )
    location: Optional[location.Location] = Field(
        None, description='The location where to move this entity to.'
    )


class LifecycleMoveAction(BaseModel):
    class Config:
        extra = Extra.forbid

    daysAfterCreation: Optional[conint(ge=1)] = Field(
        None,
        description='Number of days after creation of the entity that the move should be triggered.',
    )
    daysAfterModification: Optional[conint(ge=1)] = Field(
        None,
        description='Number of days after last modification of the entity that the move should be triggered.',
    )
    destination: Optional[Destination] = Field(
        None, description='Location where this entity needs to be moved to.'
    )



# generated by datamodel-codegen:
#   filename:  schema/metadataIngestion/databaseServiceMetadataPipeline.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from enum import Enum
from typing import Optional, Union

from pydantic import BaseModel, Extra, Field

from ..security.credentials import gcsCredentials, s3Credentials
from ..type import filterPattern


class DbtProvider(Enum):
    local = 'local'
    http = 'http'
    gcs = 'gcs'
    gcs_path = 'gcs-path'
    s3 = 's3'


class LocalHttpDBTConfig(BaseModel):
    class Config:
        extra = Extra.forbid

    dbtCatalogFilePath: str = Field(
        ...,
        description='DBT catalog file to extract dbt models with their column schemas.',
    )
    dbtManifestFilePath: str = Field(
        ...,
        description='DBT manifest file path to extract dbt models and associate with tables.',
    )


class DatabaseServiceMetadataPipeline(BaseModel):
    class Config:
        extra = Extra.forbid

    markDeletedTables: Optional[bool] = Field(
        True,
        description='Optional configuration to soft delete tables in OpenMetadata if the source tables are deleted.',
    )
    includeTables: Optional[bool] = Field(
        True,
        description='Optional configuration to turn off fetching metadata for tables.',
    )
    includeViews: Optional[bool] = Field(
        True,
        description='Optional configuration to turn off fetching metadata for views.',
    )
    generateSampleData: Optional[bool] = Field(
        True,
        description='Option to turn on/off generating sample data during metadata extraction.',
    )
    sampleDataQuery: Optional[str] = Field(
        'select * from {}.{} limit 50', description='Sample data extraction query.'
    )
    enableDataProfiler: Optional[bool] = Field(
        False,
        description='Run data profiler as part of this metadata ingestion to get table profile data.',
    )
    schemaFilterPattern: Optional[filterPattern.FilterPattern] = Field(
        None,
        description='Regex to only fetch tables or databases that matches the pattern.',
    )
    tableFilterPattern: Optional[filterPattern.FilterPattern] = Field(
        None, description='Regex exclude tables or databases that matches the pattern.'
    )
    dbtProvider: Optional[DbtProvider] = Field(
        None,
        description="Method from which the DBT files will be fetched. Accepted values are: 's3'(Required aws s3 credentials to be provided), 'gcs'(Required gcs credentials to be provided), 'gcs-path'(path of the file containing gcs credentials), 'local'(path of dbt files on local system), 'http'(url path of dbt files).",
    )
    dbtConfig: Optional[
        Union[
            LocalHttpDBTConfig,
            gcsCredentials.GCSCredentials,
            s3Credentials.S3Credentials,
        ]
    ] = Field(None, description='DBT configuration.')
    dbtCatalogFileName: Optional[str] = Field(
        'catalog.json', description='DBT Catalog file name'
    )
    dbtManifestFileName: Optional[str] = Field(
        'manifest.json', description='DBT Manifest file name'
    )



# generated by datamodel-codegen:
#   filename:  schema/tests/column/columnValuesToBeNotInSet.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import List, Union

from pydantic import BaseModel, Extra, Field


class ColumnValuesToBeNotInSet(BaseModel):
    class Config:
        extra = Extra.forbid

    forbiddenValues: List[Union[str, float]] = Field(
        ..., description='An Array of values.'
    )



# generated by datamodel-codegen:
#   filename:  schema/entity/services/connections/dashboard/redashConnection.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from enum import Enum
from typing import Optional

from pydantic import AnyUrl, BaseModel, Extra, Field

from .. import connectionBasicType


class RedashType(Enum):
    Redash = 'Redash'


class RedashConnection(BaseModel):
    class Config:
        extra = Extra.forbid

    type: Optional[RedashType] = Field('Redash', description='Service Type')
    username: str = Field(..., description='username for the Redash')
    hostPort: AnyUrl = Field(..., description='URL for the redash instance')
    apiKey: str = Field(..., description='API key of the redash instance to access.')
    supportsMetadataExtraction: Optional[
        connectionBasicType.SupportsMetadataExtraction
    ] = None



# generated by datamodel-codegen:
#   filename:  schema/tests/columnTest.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional, Union

from pydantic import BaseModel, Extra, Field

from ..type import basic, entityReference
from . import basic as basic_1
from .column import (
    columnValuesLengthsToBeBetween,
    columnValuesMissingCountToBeEqual,
    columnValuesToBeBetween,
    columnValuesToBeNotInSet,
    columnValuesToBeNotNull,
    columnValuesToBeUnique,
    columnValuesToMatchRegex,
)


class ColumnTestType(Enum):
    columnValuesToBeUnique = 'columnValuesToBeUnique'
    columnValuesToBeNotNull = 'columnValuesToBeNotNull'
    columnValuesToMatchRegex = 'columnValuesToMatchRegex'
    columnValuesToBeNotInSet = 'columnValuesToBeNotInSet'
    columnValuesToBeBetween = 'columnValuesToBeBetween'
    columnValuesMissingCountToBeEqual = 'columnValuesMissingCountToBeEqual'
    columnValueLengthsToBeBetween = 'columnValueLengthsToBeBetween'


class ColumnTestCase(BaseModel):
    class Config:
        extra = Extra.forbid

    config: Optional[
        Union[
            columnValuesToBeUnique.ColumnValuesToBeUnique,
            columnValuesToBeNotNull.ColumnValuesToBeNotNull,
            columnValuesToMatchRegex.ColumnValuesToMatchRegex,
            columnValuesToBeNotInSet.ColumnValuesToBeNotInSet,
            columnValuesToBeBetween.ColumnValuesToBeBetween,
            columnValuesMissingCountToBeEqual.ColumnValuesMissingCount,
            columnValuesLengthsToBeBetween.ColumnValueLengthsToBeBetween,
        ]
    ] = None
    columnTestType: Optional[ColumnTestType] = None


class ColumnTest(BaseModel):
    class Config:
        extra = Extra.forbid

    id: Optional[basic.Uuid] = Field(
        None, description='Unique identifier of this table instance.'
    )
    name: basic.EntityName = Field(
        ...,
        description='Name that identifies this test case. Name passed by client will be  overridden by  auto generating based on table/column name and test name',
    )
    description: Optional[str] = Field(None, description='Description of the testcase.')
    columnName: str = Field(..., description='Name of the column in a table.')
    testCase: ColumnTestCase
    executionFrequency: Optional[basic_1.TestCaseExecutionFrequency] = None
    results: Optional[List[basic_1.TestCaseResult]] = Field(
        None, description='List of results of the test case.'
    )
    owner: Optional[entityReference.EntityReference] = Field(
        None, description='Owner of this Pipeline.'
    )
    updatedAt: Optional[basic.Timestamp] = Field(
        None,
        description='Last update time corresponding to the new version of the entity in Unix epoch time milliseconds.',
    )
    updatedBy: Optional[str] = Field(None, description='User who made the update.')



# generated by datamodel-codegen:
#   filename:  schema/api/data/createDashboard.json
#   timestamp: 2022-04-20T15:52:56+00:00

from __future__ import annotations

from typing import List, Optional

from pydantic import AnyUrl, BaseModel, Extra, Field

from ...type import basic, entityReference, tagLabel


class CreateDashboardRequest(BaseModel):
    class Config:
        extra = Extra.forbid

    name: basic.EntityName = Field(
        ..., description='Name that identifies this dashboard.'
    )
    displayName: Optional[str] = Field(
        None,
        description='Display Name that identifies this Dashboard. It could be title or label from the source services',
    )
    description: Optional[str] = Field(
        None,
        description='Description of the database instance. What it has and how to use it.',
    )
    dashboardUrl: Optional[AnyUrl] = Field(None, description='Dashboard URL')
    charts: Optional[List[entityReference.EntityReference]] = Field(
        None, description='All the charts included in this Dashboard.'
    )
    tags: Optional[List[tagLabel.TagLabel]] = Field(
        None, description='Tags for this dashboard'
    )
    owner: Optional[entityReference.EntityReference] = Field(
        None, description='Owner of this dashboard'
    )
    service: entityReference.EntityReference = Field(
        ...,
        description='Link to the dashboard service where this dashboard is hosted in',
    )
